@@ -34,13 +34,13 @@
 #include <k3baudiocdtrackdrag.h>
 #include <k3bthemedlabel.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 #include <kiconloader.h>
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kstdaction.h>
-#include <kmessagebox.h>
-#include <kconfig.h>
+#include <tdemessagebox.h>
+#include <tdeconfig.h>
 #include <klineedit.h>
 #include <kcombobox.h>
 #include <kstandarddirs.h>
@@ -69,7 +69,7 @@ public:
     setText( 1, TQString::number(_trackNumber).rightJustify( 2, ' ' ) );
     setText( 3, i18n("Track %1").arg(_trackNumber) );
     setText( 4, " " + length.toString() + " " );
-    setText( 5, " " + KIO::convertSize( length.audioBytes() ) + " " );
+    setText( 5, " " + TDEIO::convertSize( length.audioBytes() ) + " " );
 
     trackNumber = _trackNumber;
 
@@ -119,21 +119,21 @@ K3bAudioCdView::K3bAudioCdView( TQWidget* parent, const char *name )
   // ----------------------------------------------------------------------------------
   m_trackView = new K3bAudioCdListView( this, mainWidget() );
 
-  connect( m_trackView, TQT_SIGNAL(itemRenamed(TQListViewItem*, const TQString&, int)),
-	   this, TQT_SLOT(slotItemRenamed(TQListViewItem*, const TQString&, int)) );
-  connect( m_trackView, TQT_SIGNAL(contextMenu(KListView*, TQListViewItem*, const TQPoint&)),
-	   this, TQT_SLOT(slotContextMenu(KListView*, TQListViewItem*, const TQPoint&)) );
-//   connect( m_trackView, TQT_SIGNAL(selectionChanged(TQListViewItem*)), 
-// 	   this, TQT_SLOT(slotTrackSelectionChanged(TQListViewItem*)) );
+  connect( m_trackView, TQ_SIGNAL(itemRenamed(TQListViewItem*, const TQString&, int)),
+	   this, TQ_SLOT(slotItemRenamed(TQListViewItem*, const TQString&, int)) );
+  connect( m_trackView, TQ_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
+	   this, TQ_SLOT(slotContextMenu(TDEListView*, TQListViewItem*, const TQPoint&)) );
+//   connect( m_trackView, TQ_SIGNAL(selectionChanged(TQListViewItem*)), 
+// 	   this, TQ_SLOT(slotTrackSelectionChanged(TQListViewItem*)) );
 
   mainGrid->addLayout( toolBoxLayout, 0, 0 );
   mainGrid->addWidget( m_trackView, 1, 0 );
 
 
-  m_cddb = new K3bCddb( TQT_TQOBJECT(this) );
+  m_cddb = new K3bCddb( this );
 
-  connect( m_cddb, TQT_SIGNAL(queryFinished(int)),
-	   this, TQT_SLOT(slotCddbQueryFinished(int)) );
+  connect( m_cddb, TQ_SIGNAL(queryFinished(int)),
+	   this, TQ_SLOT(slotCddbQueryFinished(int)) );
 
   initActions();
   //  slotTrackSelectionChanged(0);
@@ -203,7 +203,7 @@ void K3bAudioCdView::reloadMedium()
 
   updateDisplay();
 
-  KConfig* c = k3bcore->config();
+  TDEConfig* c = k3bcore->config();
   c->setGroup("Cddb");
   bool useCddb = ( c->readBoolEntry( "use local cddb query", true ) || 
 		   c->readBoolEntry( "use remote cddb", false ) );
@@ -224,41 +224,41 @@ void K3bAudioCdView::reloadMedium()
 
 void K3bAudioCdView::initActions()
 {
-  m_actionCollection = new KActionCollection( this );
+  m_actionCollection = new TDEActionCollection( this );
 
-  KAction* actionSelectAll = new KAction( i18n("Check All"), 0, 0, TQT_TQOBJECT(this),
-					  TQT_SLOT(slotCheckAll()), actionCollection(),
+  TDEAction* actionSelectAll = new TDEAction( i18n("Check All"), 0, 0, this,
+					  TQ_SLOT(slotCheckAll()), actionCollection(),
 					  "check_all" );
-  KAction* actionDeselectAll = new KAction( i18n("Uncheck All"), 0, 0, TQT_TQOBJECT(this),
-					    TQT_SLOT(slotUncheckAll()), actionCollection(),
+  TDEAction* actionDeselectAll = new TDEAction( i18n("Uncheck All"), 0, 0, this,
+					    TQ_SLOT(slotUncheckAll()), actionCollection(),
 					    "uncheck_all" );
-  KAction* actionSelect = new KAction( i18n("Check Track"), 0, 0, TQT_TQOBJECT(this),
-				       TQT_SLOT(slotSelect()), actionCollection(),
+  TDEAction* actionSelect = new TDEAction( i18n("Check Track"), 0, 0, this,
+				       TQ_SLOT(slotSelect()), actionCollection(),
 				       "select_track" );
-  KAction* actionDeselect = new KAction( i18n("Uncheck Track"), 0, 0, TQT_TQOBJECT(this),
-					 TQT_SLOT(slotDeselect()), actionCollection(),
+  TDEAction* actionDeselect = new TDEAction( i18n("Uncheck Track"), 0, 0, this,
+					 TQ_SLOT(slotDeselect()), actionCollection(),
 					 "deselect_track" );
-  KAction* actionEditTrackCddbInfo = new KAction( i18n("Edit Track cddb Info"), "edit", 0, TQT_TQOBJECT(this),
-						  TQT_SLOT(slotEditTrackCddb()), actionCollection(),
+  TDEAction* actionEditTrackCddbInfo = new TDEAction( i18n("Edit Track cddb Info"), "edit", 0, this,
+						  TQ_SLOT(slotEditTrackCddb()), actionCollection(),
 						  "edit_track_cddb" );
-  KAction* actionEditAlbumCddbInfo = new KAction( i18n("Edit Album cddb Info"), "edit", 0, TQT_TQOBJECT(this),
-						  TQT_SLOT(slotEditAlbumCddb()), actionCollection(),
+  TDEAction* actionEditAlbumCddbInfo = new TDEAction( i18n("Edit Album cddb Info"), "edit", 0, this,
+						  TQ_SLOT(slotEditAlbumCddb()), actionCollection(),
 						  "edit_album_cddb" );
 
-  KAction* actionStartRip = new KAction( i18n("Start Ripping"), "cddarip", 0, TQT_TQOBJECT(this),
-					 TQT_SLOT(startRip()), actionCollection(), "start_rip" );
+  TDEAction* actionStartRip = new TDEAction( i18n("Start Ripping"), "cddarip", 0, this,
+					 TQ_SLOT(startRip()), actionCollection(), "start_rip" );
 
-  KAction* actionQueryCddb = new KAction( i18n("Query cddb"), "reload", 0, TQT_TQOBJECT(this),
-					  TQT_SLOT(queryCddb()), actionCollection(), "query_cddb" );
+  TDEAction* actionQueryCddb = new TDEAction( i18n("Query cddb"), "reload", 0, this,
+					  TQ_SLOT(queryCddb()), actionCollection(), "query_cddb" );
 
-  KAction* actionSaveCddbLocally = new KAction( i18n("Save Cddb Entry Locally"), "filesave", 0, TQT_TQOBJECT(this),
-						TQT_SLOT(slotSaveCddbLocally()), actionCollection(), "save_cddb_local" );
+  TDEAction* actionSaveCddbLocally = new TDEAction( i18n("Save Cddb Entry Locally"), "document-save", 0, this,
+						TQ_SLOT(slotSaveCddbLocally()), actionCollection(), "save_cddb_local" );
 
   // TODO: set the actions tooltips and whatsthis infos
 
   // setup the popup menu
-  m_popupMenu = new KActionMenu( actionCollection(), "popup_menu" );
-  KAction* separator = new KActionSeparator( actionCollection(), "separator" );
+  m_popupMenu = new TDEActionMenu( actionCollection(), "popup_menu" );
+  TDEAction* separator = new TDEActionSeparator( actionCollection(), "separator" );
   m_popupMenu->insert( actionSelect );
   m_popupMenu->insert( actionDeselect );
   m_popupMenu->insert( actionSelectAll );
@@ -279,7 +279,7 @@ void K3bAudioCdView::initActions()
 }
 
 
-void K3bAudioCdView::slotContextMenu( KListView*, TQListViewItem*, const TQPoint& p )
+void K3bAudioCdView::slotContextMenu( TDEListView*, TQListViewItem*, const TQPoint& p )
 {
   m_popupMenu->popup(p);
 }
@@ -432,7 +432,7 @@ void K3bAudioCdView::slotEditAlbumCddb()
 
 void K3bAudioCdView::queryCddb()
 {
-  KConfig* c = k3bcore->config();
+  TDEConfig* c = k3bcore->config();
   c->setGroup("Cddb");
 
   m_cddb->readConfig( c );
@@ -453,7 +453,7 @@ void K3bAudioCdView::slotCddbQueryFinished( int error )
     m_cddbInfo = m_cddb->result();
 
     // save the entry locally
-    KConfig* c = k3bcore->config();
+    TDEConfig* c = k3bcore->config();
     c->setGroup( "Cddb" );
     if( c->readBoolEntry( "save cddb entries locally", true ) )
       m_cddb->saveEntry( m_cddbInfo );
@@ -461,7 +461,7 @@ void K3bAudioCdView::slotCddbQueryFinished( int error )
     updateDisplay();
   }
   else if( error == K3bCddbQuery::NO_ENTRY_FOUND ) {
-    if( !KConfigGroup( k3bcore->config(), "Cddb" ).readBoolEntry( "use remote cddb", false ) )
+    if( !TDEConfigGroup( k3bcore->config(), "Cddb" ).readBoolEntry( "use remote cddb", false ) )
       K3bPassivePopup::showPopup( i18n("<p>No CDDB entry found. Enable remote CDDB queries in the K3b settings to get access "
 				       "to more entries through the internet."), i18n("CDDB") );
     else
@@ -509,7 +509,7 @@ void K3bAudioCdView::slotSaveCddbLocally()
   // make sure the data gets updated (bad design like a lot in the cddb stuff! :(
   m_cddbInfo.rawData.truncate(0);
 
-  KConfig* c = k3bcore->config();
+  TDEConfig* c = k3bcore->config();
   c->setGroup("Cddb");
 
   m_cddb->readConfig( c );
